@@ -40,9 +40,9 @@ class Pager(GUIAddon):
 
 		onSelectionChanged = x if (x := getattr(self.source, "onSelectionChanged", None)) is not None else getattr(self.source, "onSelChanged", None)
 
-		if isinstance(onSelectionChanged, list) and self.initPager not in onSelectionChanged:
+		if (isinstance(onSelectionChanged, list) or isinstance(onSelectionChanged, List)) and self.initPager not in onSelectionChanged:
 			onSelectionChanged.append(self.initPager)
-				
+
 		self.initPager()
 
 	GUI_WIDGET = eListbox
@@ -162,6 +162,8 @@ class Pager(GUIAddon):
 	def getCurrentIndex(self):
 		if hasattr(self.source, "index"):
 			return self.source.index
+		if hasattr(self.source, "currentIndex"):
+			return self.source.currentIndex
 		return self.source.l.getCurrentSelectionIndex()
 
 	def getSourceSize(self):
@@ -176,6 +178,8 @@ class Pager(GUIAddon):
 			return len(self.source.list)
 		elif hasattr(self.source, 'l') and hasattr(self.source.l, 'getListSize'):
 			return self.source.l.getListSize()
+		elif hasattr(self.source, "totalItemsCount"):
+			return self.source.totalItemsCount
 		return 0
 
 	def getListItemSize(self):
@@ -251,7 +255,7 @@ class Pager(GUIAddon):
 			elif attrib == "showIcons":
 				self.showIcons = value
 			elif attrib == "maxPages":
-				self.max_pages = parseScale(value)
+				self.max_pages = int(value)
 			elif attrib == "orientation":
 				self.orientation = self.orientations.get(value, self.orientations["orHorizontal"])
 				if self.orientation == eListbox.orHorizontal:
