@@ -57,6 +57,7 @@ class EPGList(GUIComponent):
 		self.skinColumns = False
 		self.tw = applySkinFactor(90)
 		self.dy = 0
+		self.sidesMargin = 0
 
 		if type == EPG_TYPE_SINGLE:
 			self.l.setBuildFunc(self.buildSingleEntry)
@@ -218,15 +219,19 @@ class EPGList(GUIComponent):
 		t = localtime(beginTime)
 		res = [
 			None, # no private data needed
-			(eListboxPythonMultiContent.TYPE_TEXT, r1.x, r1.y, r1.w, r1.h, 0, RT_HALIGN_RIGHT | RT_VALIGN_CENTER, self.days[t[6]]),
-			(eListboxPythonMultiContent.TYPE_TEXT, r2.x, r2.y, r2.w, r1.h, 0, RT_HALIGN_RIGHT | RT_VALIGN_CENTER, "%02d.%02d, %02d:%02d" % (t[2], t[1], t[3], t[4]))
+			(eListboxPythonMultiContent.TYPE_TEXT, r1.x + self.sidesMargin, r1.y, r1.w, r1.h, 0, RT_HALIGN_RIGHT | RT_VALIGN_CENTER, self.days[t[6]]),
+			(eListboxPythonMultiContent.TYPE_TEXT, r2.x + self.sidesMargin, r2.y, r2.w, r1.h, 0, RT_HALIGN_RIGHT | RT_VALIGN_CENTER, "%02d.%02d, %02d:%02d" % (t[2], t[1], t[3], t[4]))
 		]
 		if clock_types:
 			for i in range(len(clock_types)):
-				res.append((eListboxPythonMultiContent.TYPE_PIXMAP_ALPHABLEND, r3.x + i * self.space, r3.y + self.dy, self.iconSize, self.iconSize, self.clocks[clock_types[i]]))
-			res.append((eListboxPythonMultiContent.TYPE_TEXT, r3.x + (i + 1) * self.space, r3.y, r3.w, r3.h, 0, RT_HALIGN_LEFT | RT_VALIGN_CENTER, EventName))
+				clockIcon = self.clocks[clock_types[i]]
+				pix_size = clockIcon.size()
+				pix_width = pix_size.width()
+				pix_height = pix_size.height()
+				res.append((eListboxPythonMultiContent.TYPE_PIXMAP_ALPHABLEND, r3.x + self.sidesMargin + i * self.space, r3.y + self.dy, pix_width, pix_height, clockIcon))
+			res.append((eListboxPythonMultiContent.TYPE_TEXT, r3.x + self.sidesMargin + (i + 1) * self.space, r3.y, r3.w, r3.h, 0, RT_HALIGN_LEFT | RT_VALIGN_CENTER, EventName))
 		else:
-			res.append((eListboxPythonMultiContent.TYPE_TEXT, r3.x, r3.y, r3.w, r3.h, 0, RT_HALIGN_LEFT | RT_VALIGN_CENTER, EventName))
+			res.append((eListboxPythonMultiContent.TYPE_TEXT, r3.x + self.sidesMargin, r3.y, r3.w, r3.h, 0, RT_HALIGN_LEFT | RT_VALIGN_CENTER, EventName))
 		return res
 
 	def buildSimilarEntry(self, service, eventId, beginTime, service_name, duration):
@@ -316,11 +321,38 @@ class EPGList(GUIComponent):
 		#print((int(time()) - t)
 		self.selectionChanged()
 
-	def fillSingleEPG(self, service):
+	def filtering_epg(self, epg_list, filtering):
+		def dailySpan(start, end):
+			return list(filter(lambda event: (start <= event_time(event) < end), epg_list))
+		def overnightSpan(start, end):
+			return list(filter(lambda event: (start <= event_time(event) < 1440 or 0 <= event_time(event) < end), epg_list))
+		def event_time(event):
+			return localtime(event[2]).tm_hour * 60 + localtime(event[2]).tm_min
+
+		def minutes(t):
+			return t[0] * 60 + t[1]
+
+		start, end = minutes(config.epg.filter_start.value), minutes(config.epg.filter_end.value)
+		if filtering == 1:
+			if start < end:
+				return dailySpan(start, end)
+			else:
+				return overnightSpan(start, end)
+		elif filtering == 2:
+			if start < end:
+				return overnightSpan(end, start)
+			else:
+				return dailySpan(end, start)
+
+	def fillSingleEPG(self, service, sorting=0, filtering=0):
 		t = int(time())
-		epg_time = t - config.epg.histminutes.getValue() * 60
+		epg_time = t - (int(config.epg.histminutes.value) * 60)
 		test = ['RIBDT', (service.ref.toString(), 0, epg_time, -1)]
 		self.list = self.queryEPG(test)
+		if filtering:
+			self.list = self.filtering_epg(self.list, filtering)
+		if config.epg.filter_keepsorting.value and sorting:
+			self.sortSingleEPG(sorting)
 		self.l.setList(self.list)
 		if t != epg_time:
 			idx = 0
@@ -391,10 +423,10 @@ class EPGList(GUIComponent):
 			print("[EPGList] wrong '%s' skin parameters" % string)
 
 		def setEventItemFont(value):
-			self.eventItemFont = parseFont(value, ((1, 1), (1, 1)))
+			self.eventItemFont = parseFont(value, parent.scale)
 
 		def setEventTimeFont(value):
-			self.eventTimeFont = parseFont(value, ((1, 1), (1, 1)))
+			self.eventTimeFont = parseFont(value, parent.scale)
 
 		def setIconDistance(value):
 			self.iconDistance = parseScale(value)
@@ -412,6 +444,9 @@ class EPGList(GUIComponent):
 			else:
 				warningWrongSkinParameter(attrib)
 
+		def sidesMargin(value):
+			self.sidesMargin = parseScale(value)
+
 		def setColGap(value):
 			self.colGap = parseScale(value)
 
