@@ -1,5 +1,5 @@
 from Components.PerServiceDisplay import PerServiceBase
-from enigma import iPlayableService, iPlayableService
+from enigma import iPlayableService, iPlayableService, eServiceCenter
 from Components.Sources.Source import Source
 from Components.Element import cached
 import NavigationInstance
@@ -23,38 +23,38 @@ class CurrentService(PerServiceBase, Source):
 				iPlayableService.evHBBTVInfo: self.serviceEvent
 			}, with_event=True)
 		self.navcore = navcore
-		self.srv = None
 		self.info = None
 		self.onManualNewService = []
 
 	def serviceEvent(self, event):
-		self.srv = None
 		self.info = None
 		self.changed((self.CHANGED_SPECIFIC, event))
 
 	@cached
 	def getCurrentService(self):
-		return self.srv or self.navcore.getCurrentService()
+		return self.navcore.getCurrentService()
+	
+	def getCurrentServiceReference(self):
+		return self.navcore.getCurrentlyPlayingServiceReference()
 
 	service = property(getCurrentService)
 
 	@cached
 	def getCurrentServiceRef(self):
 		if NavigationInstance.instance is not None:
-			return self.srv or NavigationInstance.instance.getCurrentlyPlayingServiceOrGroup()
+			return NavigationInstance.instance.getCurrentServiceReferenceOriginal()
 		return None
 
 	serviceref = property(getCurrentServiceRef)
 
 	def newService(self, ref):
 		if ref and isinstance(ref, bool):
-			self.srv = None
+			self.info = None
 		elif ref:
-			self.srv = ref
 			self.info = eServiceCenter.getInstance().info(ref)
 		else:
-			self.srv = ref
-			
+			self.info = None
+
 		for x in self.onManualNewService:
 			x()
 
