@@ -7,13 +7,13 @@ from re import escape
 from re import findall
 from re import match
 from re import search
+from re import sub
 from json import dumps
 from json import loads
 
 from Components.config import config
 
 from .compat import compat_parse_qs
-from .compat import compat_str
 from .compat import compat_Request
 from .compat import compat_urlopen
 from .compat import compat_URLError
@@ -21,6 +21,19 @@ from .compat import SUBURI
 from .jsinterp import JSInterpreter
 
 
+IGNORE_VIDEO_FORMAT = (
+	'43', '44', '45', '46',  # webm
+	'82', '83', '84', '85',  # 3D
+	'100', '101', '102',  # 3D
+	'167', '168', '169',  # webm
+	'170', '171', '172',  # webm
+	'218', '219',  # webm
+	'242', '243', '244', '245', '246', '247',  # webm
+	'394', '395', '396', '397', '398', '399', '400', '401', '402', '694', '695', '696', '697', '698', '699', '700', '701', '571',  # AV1
+	'249', '250', '251',  # webm
+	'302'  # webm
+)
+
 PRIORITY_VIDEO_FORMAT = ()
 
 
@@ -53,14 +66,13 @@ class YouTubeVideoUrl():
 		self.nsig_cache = (None, None)
 
 	@staticmethod
-	def try_get(src, get, expected_type=None):
-		try:
-			v = get(src)
-		except (AttributeError, KeyError, TypeError, IndexError):
-			pass
-		else:
-			if expected_type is None or isinstance(v, expected_type):
-				return v
+	def try_get(src, getter):
+		for x in getter:
+			if isinstance(src, dict) and x in src:
+				src = src[x]
+			else:
+				return None
+		return src
 
 	@staticmethod
 	def _guess_encoding_from_content(content_type, webpage_bytes):
@@ -121,27 +133,26 @@ class YouTubeVideoUrl():
 						)\)&&\(c=|
 					\b(?P<var>[a-zA-Z0-9_$]+)=
 				)(?P<nfunc>[a-zA-Z0-9_$]+)(?:\[(?P<idx>\d+)\])?\([a-zA-Z]\)
-				(?(var),[a-zA-Z0-9_$]+\.set\("n"\,(?P=var)\),(?P=nfunc)\.length)
+				(?(var),[a-zA-Z0-9_$]+\.set\((?:"n+"|[a-zA-Z0-9_$]+)\,(?P=var)\))
 			''', jscode
 		).group('nfunc', 'idx')
 		if not func_name:
 			print('[YouTubeVideoUrl] Falling back to generic n function search')
 			return search(
 				r'''(?xs)
-					(?:(?<=[^\w$])|^)       # instead of \b, which ignores $
-					(?P<name>(?!\d)[a-zA-Z\d_$]+)\s*=\s*function\((?!\d)[a-zA-Z\d_$]+\)
-					\s*\{(?:(?!};).)+?["']enhanced_except_
+					;\s*(?P<name>[a-zA-Z0-9_$]+)\s*=\s*function\([a-zA-Z0-9_$]+\)
+					\s*\{(?:(?!};).)+?return\s*(?P<q>["'])[\w-]+_w8_(?P=q)\s*\+\s*[a-zA-Z0-9_$]+
 				''', jscode
 			).group('name')
 		if not idx:
 			return func_name
 		if int(idx) == 0:
 			real_nfunc = search(
-				r'var %s\s*=\s*\[([a-zA-Z_$][\w$]*)\];' % (escape(func_name), ),
+				r'var %s\s*=\s*(\[.+?\])\s*[,;]' % (escape(func_name), ),
 				jscode
 			)
 			if real_nfunc:
-				return real_nfunc.group(1)
+				return real_nfunc.group(1)[1:-1]
 
 	def _extract_player_info(self):
 		res = self._download_webpage('https://www.youtube.com/iframe_api')
@@ -157,6 +168,12 @@ class YouTubeVideoUrl():
 				'https://www.youtube.com/s/player/%s/player_ias.vflset/en_US/base.js' % player_id
 			)
 
+	@staticmethod
+	def _fixup_n_function_code(argnames, code):
+		return argnames, sub(
+			r';\s*if\s*\(\s*typeof\s+[a-zA-Z0-9_$]+\s*===?\s*(["\'])undefined\1\s*\)\s*return\s+%s;' % argnames[0],
+			';', code)
+
 	def _extract_function(self, player_id, s_id):
 		if player_id not in self._player_cache:
 			self._load_player(player_id)
@@ -166,21 +183,21 @@ class YouTubeVideoUrl():
 				funcname = self._extract_n_function_name(self._player_cache[player_id])
 			else:
 				funcname = self._parse_sig_js(self._player_cache[player_id])
-			self._code_cache[s_id] = jsi.extract_function_code(funcname)
+			self._code_cache[s_id] = self._fixup_n_function_code(*jsi.extract_function_code(funcname))
 		return lambda s: jsi.extract_function_from_code(*self._code_cache[s_id])([s])
 
 	def _unthrottle_url(self, url, player_id):
 		n_param = search(r'&n=(.+?)&', url).group(1)
 		n_id = 'nsig_%s_%s' % (player_id, '.'.join(str(len(p)) for p in n_param.split('.')))
-		print('[YouTubeVideoUrl] Decrypt nsig', n_id)
 		if self.nsig_cache[0] != n_param:
+			print('[YouTubeVideoUrl] Decrypt nsig', n_id)
 			self.nsig_cache = (None, None)
 			try:
 				ret = self._extract_function(player_id, n_id)(n_param)
 			except Exception as ex:
 				print('[YouTubeVideoUrl] Unable to decode nsig', ex)
 			else:
-				if ret.startswith('enhanced_except_'):
+				if ret.startswith('enhanced_except_') or ret.endswith(n_param):
 					print('[YouTubeVideoUrl] Unhandled exception in decode', ret)
 				else:
 					self.nsig_cache = (n_param, ret)
@@ -191,16 +208,19 @@ class YouTubeVideoUrl():
 			del self._code_cache[n_id]
 		return url
 
-	def _decrypt_signature(self, s, player_id):
+	def _decrypt_signature_url(self, sc, player_id):
 		"""Turn the encrypted s field into a working signature"""
+		s = sc.get('s', [''])[0]
 		s_id = 'sig_%s_%s' % (player_id, '.'.join(str(len(p)) for p in s.split('.')))
 		print('[YouTubeVideoUrl] Decrypt signature', s_id)
 		try:
-			return self._extract_function(player_id, s_id)(s)
+			sig = self._extract_function(player_id, s_id)(s)
 		except Exception as ex:
 			print('[YouTubeVideoUrl] Signature extraction failed', ex)
 			if s_id in self._code_cache:
 				del self._code_cache[s_id]
+		else:
+			return '%s&%s=%s' % (sc['url'][0], sc['sp'][0] if 'sp' in sc else 'signature', sig)
 
 	def _parse_sig_js(self, jscode):
 
@@ -213,18 +233,18 @@ class YouTubeVideoUrl():
 			return mobj
 
 		return _search_regex(
-			(r'\b[cs]\s*&&\s*[adf]\.set\([^,]+\s*,\s*encodeURIComponent\s*\(\s*(?P<sig>[a-zA-Z0-9$]+)\(',
+			(r'\b(?P<var>[a-zA-Z0-9_$]+)&&\((?P=var)=(?P<sig>[a-zA-Z0-9_$]{2,})\(decodeURIComponent\((?P=var)\)\)',
+				r'(?P<sig>[a-zA-Z0-9_$]+)\s*=\s*function\(\s*(?P<arg>[a-zA-Z0-9_$]+)\s*\)\s*{\s*(?P=arg)\s*=\s*(?P=arg)\.split\(\s*""\s*\)\s*;\s*[^}]+;\s*return\s+(?P=arg)\.join\(\s*""\s*\)',
+				r'(?:\b|[^a-zA-Z0-9_$])(?P<sig>[a-zA-Z0-9_$]{2,})\s*=\s*function\(\s*a\s*\)\s*{\s*a\s*=\s*a\.split\(\s*""\s*\)(?:;[a-zA-Z0-9_$]{2}\.[a-zA-Z0-9_$]{2}\(a,\d+\))?',
+				# Old patterns
+				r'\b[cs]\s*&&\s*[adf]\.set\([^,]+\s*,\s*encodeURIComponent\s*\(\s*(?P<sig>[a-zA-Z0-9$]+)\(',
 				r'\b[a-zA-Z0-9]+\s*&&\s*[a-zA-Z0-9]+\.set\([^,]+\s*,\s*encodeURIComponent\s*\(\s*(?P<sig>[a-zA-Z0-9$]+)\(',
 				r'\bm=(?P<sig>[a-zA-Z0-9$]{2,})\(decodeURIComponent\(h\.s\)\)',
-				r'\bc&&\(c=(?P<sig>[a-zA-Z0-9$]{2,})\(decodeURIComponent\(c\)\)',
-				r'(?:\b|[^a-zA-Z0-9$])(?P<sig>[a-zA-Z0-9$]{2,})\s*=\s*function\(\s*a\s*\)\s*{\s*a\s*=\s*a\.split\(\s*""\s*\)(?:;[a-zA-Z0-9$]{2}\.[a-zA-Z0-9$]{2}\(a,\d+\))?',
-				r'(?P<sig>[a-zA-Z0-9$]+)\s*=\s*function\(\s*a\s*\)\s*{\s*a\s*=\s*a\.split\(\s*""\s*\)',
 				# Obsolete patterns
 				r'("|\')signature\1\s*,\s*(?P<sig>[a-zA-Z0-9$]+)\(',
 				r'\.sig\|\|(?P<sig>[a-zA-Z0-9$]+)\(',
 				r'yt\.akamaized\.net/\)\s*\|\|\s*.*?\s*[cs]\s*&&\s*[adf]\.set\([^,]+\s*,\s*(?:encodeURIComponent\s*\()?\s*(?P<sig>[a-zA-Z0-9$]+)\(',
 				r'\b[cs]\s*&&\s*[adf]\.set\([^,]+\s*,\s*(?P<sig>[a-zA-Z0-9$]+)\(',
-				r'\b[a-zA-Z0-9]+\s*&&\s*[a-zA-Z0-9]+\.set\([^,]+\s*,\s*(?P<sig>[a-zA-Z0-9$]+)\(',
 				r'\bc\s*&&\s*[a-zA-Z0-9]+\.set\([^,]+\s*,\s*\([^)]*\)\s*\(\s*(?P<sig>[a-zA-Z0-9$]+)\('),
 			jscode
 		).group('sig')
@@ -242,8 +262,16 @@ class YouTubeVideoUrl():
 					audio_urls[audio_info.get('GROUP-ID')] = audio_info.get('URI')
 		return audio_urls
 
+	@staticmethod
+	def _url_map_append(url_map, itag, url):
+		if itag not in IGNORE_VIDEO_FORMAT:
+			url_map.append({
+				'url': url,
+				'preference': PRIORITY_VIDEO_FORMAT.index(itag) if itag in PRIORITY_VIDEO_FORMAT else 100
+			})
+
 	def _extract_from_m3u8(self, manifest_url):
-		url_map = {}
+		url_map = []
 		audio_url = ''
 
 		manifest = self._download_webpage(manifest_url)
@@ -257,66 +285,110 @@ class YouTubeVideoUrl():
 			elif line.startswith('https'):
 				itag = search(r'/sgovp/[^/]+itag%3D(\d+?)/', line) or search(r'/itag/(\d+?)/', line)
 				if itag:
-					url_map[itag.group(1)] = line + audio_url
+					self._url_map_append(url_map, itag.group(1), line + audio_url)
 					audio_url = ''
-		return url_map
+		return sorted(url_map, key=lambda k: k['preference'])
 
-	def _not_in_fmt(self, fmt, itag):
-		return not (
+	def _skip_fmt(self, fmt, itag):
+		return (
 			fmt.get('targetDurationSec') or
 			fmt.get('drmFamilies') or
 			fmt.get('type') == 'FORMAT_STREAM_TYPE_OTF' or
+			itag in IGNORE_VIDEO_FORMAT or
 			itag in self.use_dash_mp4
 		)
 
-	def _extract_url(self, our_format, streaming_formats, player_id):
+	def _extract_url(self, fmt, player_id):
+		url = fmt.get('url')
+		if not url and 'signatureCipher' in fmt:
+			url = self._decrypt_signature_url(compat_parse_qs(fmt.get('signatureCipher', '')), player_id)
+		if url:
+			if '&n=' in url:
+				url = self._unthrottle_url(url, player_id)
+			return url
+
+	@staticmethod
+	def _video_pref(fmt, prefer):
+		if prefer == 100:
+			prefer = 20 if 'video/mp4' in fmt.get('mimeType').lower() else 200
+		return prefer
+
+	@staticmethod
+	def _audio_pref(fmt, prefer, get_audio):
+		audio_track = fmt.get('audioTrack', {})
+		if get_audio == '' and 'original' in audio_track.get('displayName', '').lower():
+			prefer -= 40
+		if audio_track.get('audioIsDefault'):
+			prefer -= 20
+		if prefer == 100:
+			prefer = 20 if 'audio/mp4' in fmt.get('mimeType').lower() else 200
+		return prefer
+
+	def _sort_formats(self, priority_formats, streaming_formats, get_audio=None):
+		sorted_fmt = []
 		for fmt in streaming_formats:
 			itag = str(fmt.get('itag', ''))
-			if itag == our_format and self._not_in_fmt(fmt, itag):
-				url = fmt.get('url')
-				if not url and 'signatureCipher' in fmt:
-					sc = compat_parse_qs(fmt.get('signatureCipher', ''))
-					sig = self._decrypt_signature(sc['s'][0], player_id)
-					if sig:
-						url = '%s&%s=%s' % (sc['url'][0], sc['sp'][0] if 'sp' in sc else 'signature', sig)
-				if url:
-					if '&n=' in url:
-						url = self._unthrottle_url(url, player_id)
-					return url
+			if self._skip_fmt(fmt, itag):
+				continue
+			prefer = priority_formats.index(itag) if itag in priority_formats else 100
+			prefer = self._video_pref(fmt, prefer) if get_audio is None else self._audio_pref(fmt, prefer, get_audio)
+			if prefer < 200:
+				fmt['preference'] = prefer
+				sorted_fmt.append(fmt)
+		return sorted(sorted_fmt, key=lambda k: k['preference'])
 
 	def _extract_fmt_video_format(self, streaming_formats, player_id):
-		""" Find the best format from our format priority map """
 		print('[YouTubeVideoUrl] Try fmt url')
-		for our_format in PRIORITY_VIDEO_FORMAT:
-			url = self._extract_url(our_format, streaming_formats, player_id)
+		for fmt in self._sort_formats(PRIORITY_VIDEO_FORMAT, streaming_formats):
+			url = self._extract_url(fmt, player_id)
 			if url:
 				print('[YouTubeVideoUrl] Found fmt url')
-				return url, our_format
+				return url, str(fmt.get('itag'))
 		return '', ''
 
-	def _extract_dash_audio_format(self, streaming_formats, player_id):
-		""" If DASH MP4 video add link also on Dash MP4 Audio """
+	def _extract_dash_audio_format(self, streaming_formats, player_id, lang):
+		""" If DASH MP4 video add also DASH MP4 audio track"""
 		print('[YouTubeVideoUrl] Try fmt audio url')
-		for our_format in ('141', '140', '139', '258', '265', '325', '328', '233', '234'):
-			url = self._extract_url(our_format, streaming_formats, player_id)
+		DASH_AUDIO_FORMATS = ('141', '140', '139', '258', '265', '325', '328', '233', '234')
+		for fmt in self._sort_formats(DASH_AUDIO_FORMATS, streaming_formats, lang):
+			url = self._extract_url(fmt, player_id)
 			if url:
 				print('[YouTubeVideoUrl] Found fmt audio url')
 				return url
 		return ''
 
-	def _extract_web_response(self, video_id):
-		url = 'https://www.youtube.com/watch?v=%s&bpctr=9999999999&has_verified=1' % video_id
-		webpage = self._download_webpage(url)
-		if webpage:
-			player_response = search(r'ytInitialPlayerResponse\s*=\s*({[^>]*})\s*;\s*(?:var\s+meta|</script|\n)', webpage)
-			if player_response:
-				try:
-					return loads(player_response.group(1)), self._extract_player_info()
-				except ValueError:  # pragma: no cover
-					print('[YouTubeVideoUrl] Failed to parse web JSON')
+	def _extract_signature_timestamp(self):
+		sts = None
+		player_id = self._extract_player_info()
+		if player_id:
+			if player_id not in self._player_cache:
+				self._load_player(player_id)
+			sts = search(
+				r'(?:signatureTimestamp|sts)\s*:\s*(?P<sts>\d{5})',
+				self._player_cache[player_id]
+			).group('sts')
+		return sts, player_id
+
+	def _extract_visitor_id(self, webpage):
+		ytcfg = search(r'ytcfg\.set\s*\(\s*({.+?})\s*\)\s*;', webpage)
+		if ytcfg:
+			try:
+				return self.try_get(loads(ytcfg.group(1)), ('INNERTUBE_CONTEXT', 'client', 'visitorData'))
+			except ValueError:  # pragma: no cover
+				pass
+		print('[YouTubeVideoUrl] Failed to extract visitor id')
+
+	def _extract_web_response(self, webpage):
+		player_response = search(r'ytInitialPlayerResponse\s*=\s*({[^>]*})\s*;\s*(?:var\s+meta|</script|\n)', webpage)
+		if player_response:
+			try:
+				return loads(player_response.group(1)), self._extract_player_info()
+			except ValueError:  # pragma: no cover
+				pass
+		print('[YouTubeVideoUrl] Failed to extract web response')
 		return None, None
 
-	def _extract_player_response(self, video_id, yt_auth, client):
+	def _extract_player_response(self, video_id, yt_auth, client, lang, webpage=None):
 		player_id = None
 		url = 'https://www.youtube.com/youtubei/v1/player?prettyPrint=false'
 		data = {
@@ -325,6 +397,11 @@ class YouTubeVideoUrl():
 				'contentPlaybackContext': {
 					'html5Preference': 'HTML5_PREF_WANTS'
 				}
+			},
+			'context': {
+				'client': {
+					'hl': lang if lang else 'en'
+				}
 			}
 		}
 		headers = {
@@ -334,59 +411,51 @@ class YouTubeVideoUrl():
 		}
 		if yt_auth:
 			headers['Authorization'] = yt_auth
-		if client == 5:
-			VERSION = '19.09.3'
-			USER_AGENT = 'com.google.ios.youtube/%s (iPhone14,3; U; CPU iOS 15_6 like Mac OS X)' % VERSION
-			data['context'] = {
-				'client': {
-					'hl': config.plugins.YouTube.searchLanguage.value,
-					'clientVersion': VERSION,
-					'clientName': 'IOS',
-					'deviceModel': 'iPhone14,3',
-					'userAgent': USER_AGENT
-				}
-			}
-			headers['X-YouTube-Client-Version'] = VERSION
-			headers['User-Agent'] = USER_AGENT
-		elif client == 85:
-			player_id = self._extract_player_info()
-			if player_id:
-				if player_id not in self._player_cache:
-					self._load_player(player_id)
-				sts = search(
-					r'(?:signatureTimestamp|sts)\s*:\s*(?P<sts>\d{5})',
-					self._player_cache[player_id]
-				).group('sts')
-				if sts:
-					data['playbackContext']['contentPlaybackContext']['signatureTimestamp'] = sts
-			data['context'] = {
-				'client': {
-					'hl': config.plugins.YouTube.searchLanguage.value,
-					'clientName': 'TVHTML5_SIMPLY_EMBEDDED_PLAYER',
-					'clientVersion': '2.0',
-				},
-				'thirdParty': {
-					'embedUrl': 'https://www.youtube.com/'
-				}
-			}
-			headers['X-YouTube-Client-Version'] = '2.0'
-		else:
-			VERSION = '1.9'
-			USER_AGENT = 'com.google.android.youtube/%s (Linux; U; Android 12; US) gzip' % VERSION
-			data['context'] = {
-				'client': {
-					'hl': config.plugins.YouTube.searchLanguage.value,
-					'clientVersion': VERSION,
-					'androidSdkVersion': 31,
-					'clientName': 'ANDROID_TESTSUITE',
-					'osName': 'Android',
-					'osVersion': '12',
-					'userAgent': USER_AGENT
-				}
+		if client == 3:
+			VERSION = '19.44.38'
+			USER_AGENT = 'com.google.android.youtube/%s (Linux; U; Android 11) gzip' % VERSION
+			CLIENT_CONTEXT = {
+				'clientName': 'ANDROID',
+				'androidSdkVersion': 30,
+				'osName': 'Android',
+				'osVersion': '11'
 			}
 			data['params'] = '2AMB'
-			headers['X-YouTube-Client-Version'] = VERSION
+		elif client == 5:
+			VERSION = '20.03.02'
+			USER_AGENT = 'com.google.ios.youtube/%s (iPhone16,2; U; CPU iOS 18_2_1 like Mac OS X;)' % VERSION
+			CLIENT_CONTEXT = {
+				'clientName': 'IOS',
+				'deviceMake': 'Apple',
+				'deviceModel': 'iPhone16,2',
+				'osName': 'iPhone',
+				'osVersion': '18.2.1.22C161'
+			}
+		elif client == 7:
+			VERSION = '7.20250129.15.00'
+			USER_AGENT = 'Mozilla/5.0 (ChromiumStylePlatform) Cobalt/Version,gzip(gfe)'
+			CLIENT_CONTEXT = {'clientName': 'TVHTML5'}
+		elif client == 56:
+			VERSION = '1.20241201.00.00'
+			USER_AGENT = None
+			CLIENT_CONTEXT = {'clientName': 'WEB_EMBEDDED_PLAYER'}
+		else:
+			VERSION = '2.0'
+			USER_AGENT = None
+			CLIENT_CONTEXT = {'clientName': 'TVHTML5_SIMPLY_EMBEDDED_PLAYER'}
+			data['context']['thirdParty'] = {'embedUrl': 'https://www.youtube.com/'}
+		data['context']['client']['clientVersion'] = VERSION
+		data['context']['client'].update(CLIENT_CONTEXT)
+		if USER_AGENT:
+			data['context']['client']['userAgent'] = USER_AGENT
 			headers['User-Agent'] = USER_AGENT
+		if client in (7, 56, 85):
+			sts, player_id = self._extract_signature_timestamp()
+			if sts:
+				data['playbackContext']['contentPlaybackContext']['signatureTimestamp'] = sts
+		if client in (5, 7):
+			headers['X-Goog-Visitor-Id'] = self._extract_visitor_id(webpage) or ''
+		headers['X-YouTube-Client-Version'] = VERSION
 		try:
 			return loads(self._download_webpage(url, data, headers)), player_id
 		except ValueError:  # pragma: no cover
@@ -394,18 +463,6 @@ class YouTubeVideoUrl():
 			return None, None
 
 	def _real_extract(self, video_id, yt_auth):
-		IGNORE_VIDEO_FORMAT = (
-			'43', '44', '45', '46',  # webm
-			'82', '83', '84', '85',  # 3D
-			'100', '101', '102',  # 3D
-			'167', '168', '169',  # webm
-			'170', '171', '172',  # webm
-			'218', '219',  # webm
-			'242', '243', '244', '245', '246', '247',  # webm
-			'394', '395', '396', '397', '398', '399', '400', '401', '402', '694', '695', '696', '697', '698', '699', '700', '701', '571',  # AV1
-			'249', '250', '251',  # webm
-			'302'  # webm
-		)
 		DASHMP4_FORMAT = (
 			'133', '134', '135', '136', '137', '138', '160',
 			'212', '229', '230', '231', '232', '248', '264',
@@ -413,6 +470,7 @@ class YouTubeVideoUrl():
 			'303', '313', '315', '308'
 		)
 		url = ''
+		lang = config.plugins.YouTube.searchLanguage.value
 
 		if config.plugins.YouTube.useDashMP4.value:
 			self.use_dash_mp4 = ()
@@ -420,38 +478,37 @@ class YouTubeVideoUrl():
 			print('[YouTubeVideoUrl] skip DASH MP4 format')
 			self.use_dash_mp4 = DASHMP4_FORMAT
 
-		player_response, player_id = self._extract_player_response(video_id, yt_auth, 30)
+		player_response, player_id = self._extract_player_response(video_id, None, 3, lang)
 		if not player_response:
 			raise RuntimeError('Player response not found!')
 
-		if self.try_get(player_response, lambda x: x['videoDetails']['videoId']) != video_id:
-			if self.use_dash_mp4:
-				print('[YouTubeVideoUrl] Got wrong player response, try web response')
-				player_response, player_id = self._extract_web_response(video_id)
+		is_live = self.try_get(player_response, ('videoDetails', 'isLive'))
+
+		if self.try_get(player_response, ('videoDetails', 'videoId')) != video_id:
+			webpage = self._download_webpage('https://www.youtube.com/watch?v=%s&bpctr=9999999999&has_verified=1' % video_id)
+			if not webpage:
+				raise RuntimeError('Webpage not found!')
+
+			if not is_live:
+				print('[YouTubeVideoUrl] Got wrong player response, try mweb response')
+				player_response, player_id = self._extract_player_response(video_id, None, 7, lang, webpage)
 			else:
-				print('[YouTubeVideoUrl] Got wrong player response, try ios client')
-				player_response, player_id = self._extract_player_response(video_id, yt_auth, 5)
+				if self.use_dash_mp4:
+					print('[YouTubeVideoUrl] Got wrong player response, try for live web response')
+					player_response, player_id = self._extract_web_response(webpage)
+				else:
+					print('[YouTubeVideoUrl] Got wrong player response, try for live ios client')
+					player_response, player_id = self._extract_player_response(video_id, None, 5, lang, webpage)
 
-		is_live = self.try_get(player_response, lambda x: x['videoDetails']['isLive'])
-		playability_status = player_response.get('playabilityStatus', {})
-
-		if not is_live and playability_status.get('status') == 'LOGIN_REQUIRED':
-			print('[YouTubeVideoUrl] Age gate content')
-			player_response, player_id = self._extract_player_response(video_id, yt_auth, 85)
+		if self.try_get(player_response, ('playabilityStatus', 'status')) == 'LOGIN_REQUIRED':
+			print('[YouTubeVideoUrl] Age gate content, try web embedded client')
+			player_response, player_id = self._extract_player_response(video_id, None, 56, lang)
+			if not player_response or self.try_get(player_response, ('playabilityStatus', 'status')) != 'OK':
+				print('[YouTubeVideoUrl] Player response is not usable, try authorized tv embedded client')
+				player_response, player_id = self._extract_player_response(video_id, yt_auth, 85, lang)
 			if not player_response:
 				raise RuntimeError('Age gate content player response not found!')
 
-			playability_status = player_response.get('playabilityStatus', {})
-
-		trailer_video_id = self.try_get(
-			playability_status,
-			lambda x: x['errorScreen']['playerLegacyDesktopYpcTrailerRenderer']['trailerVideoId'],
-			compat_str
-		)
-		if trailer_video_id:
-			print('[YouTubeVideoUrl] Trailer video')
-			return str(trailer_video_id)
-
 		streaming_data = player_response.get('streamingData', {})
 		streaming_formats = streaming_data.get('formats', [])
 
@@ -463,40 +520,21 @@ class YouTubeVideoUrl():
 			streaming_formats.extend(streaming_data.get('adaptiveFormats', []))
 			url, our_format = self._extract_fmt_video_format(streaming_formats, player_id)
 			if url and our_format in DASHMP4_FORMAT:
-				audio_url = self._extract_dash_audio_format(streaming_formats, player_id)
+				audio_url = self._extract_dash_audio_format(streaming_formats, player_id, lang)
 				if audio_url:
 					url += SUBURI + audio_url
-			if not url:  # pragma: no cover
-				for fmt in streaming_formats:
-					itag = str(fmt.get('itag', ''))
-					if itag not in IGNORE_VIDEO_FORMAT and self._not_in_fmt(fmt, itag):
-						url = fmt.get('url')
-						if url:
-							break
-			if not url and streaming_formats:  # pragma: no cover
-				url = streaming_formats[0].get('url', '')
 
 		if not url:
 			print('[YouTubeVideoUrl] Try manifest url')
 			hls_manifest_url = streaming_data.get('hlsManifestUrl')
 			if hls_manifest_url:
-				url_map = self._extract_from_m3u8(hls_manifest_url)
-
-				# Find the best format from our format priority map
-				for our_format in PRIORITY_VIDEO_FORMAT:
-					if our_format in url_map:
-						url = url_map[our_format]
-						break
-				# If anything not found, used first in the list if it not in ignore map
-				if not url:  # pragma: no cover
-					for url_map_key in list(url_map.keys()):
-						if url_map_key not in IGNORE_VIDEO_FORMAT:
-							url = url_map[url_map_key]
-							break
-				if not url and url_map:  # pragma: no cover
-					url = list(url_map.values())[0]
+				for fmt in self._extract_from_m3u8(hls_manifest_url):
+					url = fmt.get('url')
+					print('[YouTubeVideoUrl] Found manifest url')
+					break
 
 		if not url:
+			playability_status = player_response.get('playabilityStatus', {})
 			reason = playability_status.get('reason')
 			if reason:
 				subreason = playability_status.get('messages')
